@@ -1,3 +1,27 @@
+#------------------------------------------------------------------------------#
+#
+#                /$$
+#               | $$
+#     /$$$$$$  /$$$$$$
+#    /$$__  $$|_  $$_/
+#   | $$  \ $$  | $$
+#   | $$  | $$  | $$ /$$
+#   |  $$$$$$$  |  $$$$/
+#    \____  $$   \___/
+#    /$$  \ $$
+#   |  $$$$$$/
+#    \______/
+#
+#  This file is part of the 'rstudio/gt' project.
+#
+#  Copyright (c) 2018-2024 gt authors
+#
+#  For full copyright and license information, please look at
+#  https://gt.rstudio.com/LICENSE.html
+#
+#------------------------------------------------------------------------------#
+
+
 #' Perform data cell colorization
 #'
 #' @description
@@ -42,76 +66,181 @@
 #' without running into too many errors.
 #'
 #' @inheritParams fmt_number
-#' @param columns,rows The columns and rows to which cell data color operations
-#'   are constrained.
-#' @param direction Should the color computations be performed column-wise or
-#'   row-wise? By default this is set with the `"column"` keyword and colors
-#'   will be applied down columns. The alternative option with the `"row"`
-#'   keyword ensures that the color mapping works across rows.
-#' @param target_columns For indirect column coloring treatments, we can supply
-#'   the columns that will receive the styling. The necessary precondition is
-#'   that we must use `direction = "column"`. If `columns` resolves to a single
-#'   column then we may use one or more columns in `target_columns`. If on the
-#'   other hand `columns` resolves to multiple columns, then `target_columns`
-#'   must resolve to the same multiple.
-#' @param method A method for computing color based on the data within body
-#'   cells. Can be `"auto"` (the default), `"numeric"`, `"bin"`, `"quantile"`,
-#'   or `"factor"`. The `"auto"` method will automatically choose the
-#'   `"numeric"` method for numerical input data or the `"factor"` method for
-#'   any non-numeric inputs.
-#' @param palette A vector of color names, the name of an **RColorBrewer**
-#'   palette, the name of a **viridis** palette, or a discrete palette
-#'   accessible from the **paletteer** package using the `<package>::<palette>`
-#'   syntax (e.g., `"wesanderson::IsleofDogs1"`). If providing a vector of
-#'   colors as a palette, each color value provided must either be a color name
-#'   (Only R/X11 color names or CSS 3.0 color names) or a hexadecimal string in
-#'   the form of `"#RRGGBB"` or `"#RRGGBBAA"`. If nothing is provided here, the
-#'   default R color palette is used (i.e., the colors from `palette()`).
-#' @param domain The possible values that can be mapped. For the `"numeric"` and
-#'   `"bin"` methods, this can be a numeric range specified with a length of two
-#'   vector. Representative numeric data is needed for the `"quantile"` method
-#'   and categorical data must be used for the `"factor"` method. If `NULL` (the
+#'
+#' @param columns *Columns to target*
+#'
+#'   `<column-targeting expression>` // *default:* `everything()`
+#'
+#'   The columns to which cell data color operations are constrained. Can either
+#'   be a series of column names provided in [c()], a vector of column indices,
+#'   or a select helper function. Examples of select helper functions include
+#'   [starts_with()], [ends_with()], [contains()], [matches()], [one_of()],
+#'   [num_range()], and [everything()].
+#'
+#' @param rows *Rows to target*
+#'
+#'   `<row-targeting expression>` // *default:* `everything()`
+#'
+#'   In conjunction with `columns`, we can specify which of their rows should
+#'   form a constraint for cell data color operations. The default
+#'   [everything()] results in all rows in `columns` being formatted.
+#'   Alternatively, we can supply a vector of row IDs within [c()], a vector of
+#'   row indices, or a select helper function. Examples of select helper
+#'   functions include [starts_with()], [ends_with()], [contains()],
+#'   [matches()], [one_of()], [num_range()], and [everything()]. We can also use
+#'   expressions to filter down to the rows we need (e.g., `[colname_1] > 100 &
+#'   [colname_2] < 50`).
+#'
+#' @param direction *Color computation direction*
+#'
+#'   `singl-kw:[column|row]` // *default:* `"column"`
+#'
+#'   Should the color computations be performed column-wise or row-wise? By
+#'   default this is set with the `"column"` keyword and colors will be applied
+#'   down columns. The alternative option with the `"row"` keyword ensures that
+#'   the color mapping works across rows.
+#'
+#' @param target_columns *Indirect columns to target*
+#'
+#'   `<row-targeting expression>` // *default:* `NULL` `optional`
+#'
+#'   For indirect column coloring treatments, we can supply the columns that
+#'   will receive the styling. The necessary precondition is that we must use
+#'   `direction = "column"`. If `columns` resolves to a single column then we
+#'   may use one or more columns in `target_columns`. If on the other hand
+#'   `columns` resolves to multiple columns, then `target_columns` must resolve
+#'   to the same multiple.
+#'
+#' @param method *Color computation method*
+#'
+#'   `singl-kw:[auto|numeric|bin|quantile|factor]` // *default:* `"auto"`
+#'
+#'   A method for computing color based on the data within body cells. Can be
+#'   `"auto"` (the default), `"numeric"`, `"bin"`, `"quantile"`, or `"factor"`.
+#'   The `"auto"` method will automatically choose the `"numeric"` method for
+#'   numerical input data or the `"factor"` method for any non-numeric inputs.
+#'
+#' @param palette *Color palette*
+#'
+#'   `vector<character>` // *default:* `NULL` (`optional`)
+#'
+#'   A vector of color names, the name of an **RColorBrewer** palette, the name
+#'   of a **viridis** palette, or a discrete palette accessible from the
+#'   **paletteer** package using the `<package>::<palette>` syntax (e.g.,
+#'   `"wesanderson::IsleofDogs1"`). If providing a vector of colors as a
+#'   palette, each color value provided must either be a color name (Only R/X11
+#'   color names or CSS 3.0 color names) or a hexadecimal string in the form of
+#'   `"#RRGGBB"` or `"#RRGGBBAA"`. If nothing is provided here, the default R
+#'   color palette is used (i.e., the colors from `palette()`).
+#'
+#' @param domain *Value domain*
+#'
+#'   `vector<numeric|integer|character>` // *default:* `NULL` (`optional`)
+#'
+#'   The possible values that can be mapped. For the `"numeric"` and `"bin"`
+#'   methods, this can be a numeric range specified with a length of two vector.
+#'   Representative numeric data is needed for the `"quantile"` method and
+#'   categorical data must be used for the `"factor"` method. If `NULL` (the
 #'   default value), the values in each column or row (depending on `direction`)
 #'   value will represent the domain.
-#' @param bins For `method = "bin"` this can either be a numeric vector of two
-#'   or more unique cut points, or, a single numeric value (greater than or
-#'   equal to `2`) giving the number of intervals into which the domain values
-#'   are to be cut. By default, this is `8`.
-#' @param quantiles For `method = "quantile"` this is the number of equal-size
-#'   quantiles to use. By default, this is set to `4`.
-#' @param levels For `method = "factor"` this allows for an alternate way of
-#'   specifying levels. If anything is provided here then any value supplied to
-#'   `domain` will be ignored. This should be a character vector of unique
-#'   values.
-#' @param ordered For `method = "factor"`, setting this to `TRUE` means that the
-#'   vector supplied to `domain` will be treated as being in the correct order
-#'   if that vector needs to be coerced to a factor. By default, this is
-#'   `FALSE`.
-#' @param na_color The color to use for missing values. By default (with
-#'   `na_color = NULL`) gray, `"#808080"`, will be used.
-#' @param alpha An optional, fixed alpha transparency value that will be applied
-#'   to all of the `colors` provided (regardless of whether a color palette was
-#'   directly supplied or generated through a color mapping function).
-#' @param reverse Should the colors computed operate in reverse order?
-#'   If `TRUE` then colors that normally change from red to blue will change in
-#'   the opposite direction. By default, this is `FALSE`.
-#' @param fn A color-mapping function. The function should be able to take a
-#'   vector of data values as input and return an equal-length vector of color
-#'   values. The `col_*()` functions provided in the **scales** package (i.e.,
+#'
+#' @param bins *Specification of bin number*
+#'
+#'   `scalar<numeric|integer>` // *default:* `8`
+#'
+#'   For `method = "bin"` this can either be a numeric vector of two or more
+#'   unique cut points, or, a single numeric value (greater than or equal to
+#'   `2`) giving the number of intervals into which the domain values are to be
+#'   cut. By default, this is `8`.
+#'
+#' @param quantiles *Specification of quantile number*
+#'
+#'   `scalar<numeric|integer>` // *default:* `4`
+#'
+#'   For `method = "quantile"` this is the number of equal-size quantiles to
+#'   use. By default, this is set to `4`.
+#'
+#' @param levels *Specification of factor levels*
+#'
+#'   `vector<character>` // *default:* `NULL` (`optional`)
+#'
+#'   For `method = "factor"` this allows for an alternate way of specifying
+#'   levels. If anything is provided here then any value supplied to `domain`
+#'   will be ignored. This should be a character vector of unique values.
+#'
+#' @param ordered *Use an ordered factor*
+#'
+#'   `scalar<logical>` // *default:* `FALSE`
+#'
+#'   For `method = "factor"`, setting this to `TRUE` means that the vector
+#'   supplied to `domain` will be treated as being in the correct order if that
+#'   vector needs to be coerced to a factor. By default, this is `FALSE`.
+#'
+#' @param na_color *Default color for `NA` values*
+#'
+#'   `scalar<character>` // *default:* `NULL` (`optional`)
+#'
+#'   The color to use for missing values. By default (with `na_color = NULL`),
+#'   the color gray (`"#808080"`) will be used. This option has no effect if
+#'   providing a color-mapping function to `fn`.
+#'
+#' @param alpha *Transparency value*
+#'
+#'   `scalar<numeric|integer>(0>=val>=1)` // *default:* `NULL` (`optional`)
+#'
+#'   An optional, fixed alpha transparency value that will be applied to all
+#'   color palette values (regardless of whether a color palette was directly
+#'   supplied in `palette` or generated through a color mapping function via
+#'   `fn`).
+#'
+#' @param reverse *Reverse order of computed colors*
+#'
+#'   `scalar<logical>` // *default:* `FALSE`
+#'
+#'   Should the colors computed operate in the reverse order? If `TRUE` then
+#'   colors that normally change from red to blue will change in the opposite
+#'   direction.
+#'
+#' @param fn *Color-mapping function*
+#'
+#'   `function` // *default:* `NULL` (`optional`)
+#'
+#'   A color-mapping function. The function should be able to take a vector of
+#'   data values as input and return an equal-length vector of color values. The
+#'   `col_*()` functions provided in the **scales** package (i.e.,
 #'   [scales::col_numeric()], [scales::col_bin()], and [scales::col_factor()])
 #'   can be invoked here with options, as those functions themselves return a
 #'   color-mapping function.
-#' @param apply_to Which style element should the colors be applied to? Options
-#'   include the cell background (the default, given as `"fill"`) or the cell
-#'   text (`"text"`).
-#' @param autocolor_text An option to let **gt** modify the coloring of text
-#'   within cells undergoing background coloring. This will result in better
-#'   text-to-background color contrast. By default, this is set to `TRUE`.
-#' @param contrast_algo The color contrast algorithm to use when
-#'   `autocolor_text = TRUE`. By default this is `"apca"` (Accessible Perceptual
-#'   Contrast Algorithm) and the alternative to this is `"wcag"` (Web Content
-#'   Accessibility Guidelines).
-#' @param colors Deprecated. Use the `fn` argument instead to provide a
+#'
+#' @param apply_to *How to apply color*
+#'
+#'   `singl-kw:[fill|text]` // *default:* `"fill"`
+#'
+#'   Which style element should the colors be applied to? Options include the
+#'   cell background (the default, given as `"fill"`) or the cell text
+#'   (`"text"`).
+#'
+#' @param autocolor_text *Automatically recolor text*
+#'
+#'   `scalar<logical>` // *default:* `TRUE`
+#'
+#'   An option to let **gt** modify the coloring of text within cells undergoing
+#'   background coloring. This will result in better text-to-background color
+#'   contrast. By default, this is set to `TRUE`.
+#'
+#' @param contrast_algo *Color contrast algorithm choice*
+#'
+#'   `singl-kw:[apca|wcag]` // *default:* `"apca"`
+#'
+#'   The color contrast algorithm to use when `autocolor_text = TRUE`. By
+#'   default this is `"apca"` (Accessible Perceptual Contrast Algorithm) and the
+#'   alternative to this is `"wcag"` (Web Content Accessibility Guidelines).
+#'
+#' @param colors *[Deprecated] Color mapping function*
+#'
+#'   `function` // *default:* `NULL` (`optional`)
+#'
+#'   This argument is deprecated. Use the `fn` argument instead to provide a
 #'   **scales**-based color-mapping function. If providing a palette, use the
 #'   `palette` argument.
 #'
@@ -294,8 +423,8 @@
 #' of every column with the default palette in R (accessed through `palette()`).
 #' The default method for applying color is `"auto"`, where numeric values will
 #' use the `"numeric"` method and character or factor values will use the
-#' `"factor"` method. The text color will be undergo modification automatically
-#' to maximize contrast (since `autocolor_text` is `TRUE` by default).
+#' `"factor"` method. The text color undergoes an automatic modification that
+#' maximizes contrast (since `autocolor_text` is `TRUE` by default).
 #'
 #' You can use any of the available `method` keywords and **gt** will only apply
 #' color to the compatible values. Let's use the `"numeric"` method and supply
@@ -349,15 +478,16 @@
 #'
 #' ```r
 #' countrypops |>
-#'   dplyr::filter(country_name == "Mongolia") |>
+#'   dplyr::filter(country_name == "Bangladesh") |>
 #'   dplyr::select(-contains("code")) |>
-#'   tail(10) |>
+#'   dplyr::slice_tail(n = 10) |>
 #'   gt() |>
 #'   data_color(
 #'     columns = population,
 #'     method = "numeric",
 #'     palette = "viridis",
-#'     domain = c(2.5E6, 3.4E6)
+#'     domain = c(150E6, 170E6),
+#'     reverse = TRUE
 #'   )
 #' ```
 #'
@@ -368,20 +498,21 @@
 #' We can alternatively use the `fn` argument for supplying the **scales**-based
 #' function [scales::col_numeric()]. That function call will itself return a
 #' function (which is what the `fn` argument actually requires) that takes a
-#' vector of numeric values and returns color values. Here is the more complex
+#' vector of numeric values and returns color values. Here is an alternate
 #' version of the code that returns the same table as in the previous example.
 #'
 #' ```r
 #' countrypops |>
-#'   dplyr::filter(country_name == "Mongolia") |>
+#'   dplyr::filter(country_name == "Bangladesh") |>
 #'   dplyr::select(-contains("code")) |>
-#'   tail(10) |>
+#'   dplyr::slice_tail(n = 10) |>
 #'   gt() |>
 #'   data_color(
 #'     columns = population,
 #'     fn = scales::col_numeric(
 #'       palette = "viridis",
-#'       domain = c(2.5E6, 3.4E6)
+#'       domain = c(150E6, 170E6),
+#'       reverse = TRUE
 #'     )
 #'   )
 #' ```
@@ -547,7 +678,7 @@
 #'
 #' @family data formatting functions
 #' @section Function ID:
-#' 3-30
+#' 3-32
 #'
 #' @section Function Introduced:
 #' `v0.2.0.5` (March 31, 2020)
@@ -593,9 +724,7 @@ data_color <- function(
   contrast_algo <- rlang::arg_match(contrast_algo)
 
   # If no color is provided to `na_color`, use gray as a default
-  if (is.null(na_color)) {
-    na_color <- "#808080"
-  }
+  na_color <- na_color %||% "#808080"
 
   # Defuse any function supplied to `fn`; if a function is supplied to `colors`
   # (previous argument for this purpose) then let that take precedent and
@@ -657,14 +786,10 @@ data_color <- function(
       # Determine if the paletteer package is installed and stop the
       # function if it is not present
 
-      if (!requireNamespace("paletteer", quietly = TRUE)) {
-
-        cli::cli_abort(c(
-          "The `paletteer` package is required for accessing palettes with
-          the `<package>::<palette>` syntax.",
-          "*" = "It can be installed with `install.packages(\"paletteer\")`."
-        ))
-      }
+      rlang::check_installed(
+        "paletteer",
+        reason = "to use palettes with the <package>::<palette> syntax."
+        )
 
       # Parse the `palette` string and extract the two different
       # components: the package that the palette comes from and the
@@ -739,10 +864,10 @@ data_color <- function(
     if (direction != "column") {
 
       cli::cli_abort(c(
-        "Specification of `target_columns` can only be done with the
-        `direction = \"column\"` option.",
+        "Specification of {.arg target_columns} can only be done with the
+        `direction = {.val column}` option.",
         "*" = "Please modify the `direction` option or remove any values in
-        `target_columns`."
+        {.arg target_columns}."
       ))
     }
 
@@ -755,8 +880,8 @@ data_color <- function(
     if (resolv_col_length > 1 && resolv_col_length != target_col_length) {
 
       cli::cli_abort(c(
-        "If the length of resolved `columns` is greater than one it must match
-        the length of the resolved `target_columns`.",
+        "If the length of resolved {.arg columns} is greater than one it must match
+        the length of the resolved {.arg target_columns}.",
         "*" = "Please ensure these greater-than-one lengths are the same."
       ))
     }
@@ -820,7 +945,7 @@ data_color <- function(
         color_fn <-
           scales::col_numeric(
             palette = palette,
-            domain = if (is.null(domain)) data_vals else domain,
+            domain = domain %||% data_vals,
             na.color = na_color,
             alpha = TRUE,
             reverse = reverse
@@ -843,7 +968,7 @@ data_color <- function(
         color_fn <-
           scales::col_factor(
             palette = palette,
-            domain = if (is.null(domain)) data_vals else domain,
+            domain = domain %||% data_vals,
             levels = levels,
             ordered = ordered,
             na.color = na_color,
@@ -857,10 +982,10 @@ data_color <- function(
       if (!is.numeric(data_vals) && direction == "row") {
 
         cli::cli_abort(c(
-          "The \"numeric\" method with `direction == \"row\"` cannot be used
+          "The {.val numeric} method with {.code direction == {.val row}} cannot be used
           when non-numeric columns are included.",
           "*" = "Either specify a collection of numeric columns or use the
-          \"factor\" method."
+          {.val factor} method."
         ))
       }
 
@@ -870,7 +995,7 @@ data_color <- function(
       color_fn <-
         scales::col_numeric(
           palette = palette,
-          domain = if (is.null(domain)) data_vals else domain,
+          domain = domain %||% data_vals,
           na.color = na_color,
           alpha = TRUE,
           reverse = reverse
@@ -884,7 +1009,7 @@ data_color <- function(
       color_fn <-
         scales::col_bin(
           palette = palette,
-          domain = if (is.null(domain)) data_vals else domain,
+          domain = domain %||% data_vals,
           bins = bins,
           pretty = FALSE,
           na.color = na_color,
@@ -901,7 +1026,7 @@ data_color <- function(
       color_fn <-
         scales::col_quantile(
           palette = palette,
-          domain = if (is.null(domain)) data_vals else domain,
+          domain = domain %||% data_vals,
           n = quantiles,
           na.color = na_color,
           alpha = TRUE,
@@ -921,7 +1046,7 @@ data_color <- function(
       color_fn <-
         scales::col_factor(
           palette = palette,
-          domain = if (is.null(domain)) data_vals else domain,
+          domain = domain %||% data_vals,
           levels = levels,
           ordered = ordered,
           na.color = na_color,
@@ -1241,8 +1366,8 @@ rgba_to_hex <- function(colors) {
 html_color <- function(colors, alpha = NULL) {
 
   # Stop function if there are any NA values in `colors`
-  if (any(is.na(colors))) {
-    cli::cli_abort("No values supplied in `colors` should be `NA`.")
+  if (anyNA(colors)) {
+    cli::cli_abort("`colors` should not contain any `NA` values.")
   }
 
   is_rgba <- is_rgba_col(colors = colors)
