@@ -1,3 +1,27 @@
+#------------------------------------------------------------------------------#
+#
+#                /$$
+#               | $$
+#     /$$$$$$  /$$$$$$
+#    /$$__  $$|_  $$_/
+#   | $$  \ $$  | $$
+#   | $$  | $$  | $$ /$$
+#   |  $$$$$$$  |  $$$$/
+#    \____  $$   \___/
+#    /$$  \ $$
+#   |  $$$$$$/
+#    \______/
+#
+#  This file is part of the 'rstudio/gt' project.
+#
+#  Copyright (c) 2018-2024 gt authors
+#
+#  For full copyright and license information, please look at
+#  https://gt.rstudio.com/LICENSE.html
+#
+#------------------------------------------------------------------------------#
+
+
 # Define the contexts
 all_contexts <- c("html", "latex", "rtf", "word", "default")
 
@@ -599,6 +623,12 @@ perform_col_merge <- function(data, context) {
       pattern <- col_merge[[i]][["pattern"]]
       sep <- col_merge[[i]][["sep"]]
 
+      # Replace any fullwidth tilde characters (the range separator in
+      # the 'ja' locale) with standard `~` in the LaTeX rendering context
+      if (grepl("\UFF5E", sep) && context == "latex") {
+        sep <- gsub("\UFF5E", "~", sep)
+      }
+
       # Transform the separator text depending on specific
       # inputs and the `context`
       sep <- context_dash_mark(sep, context = context)
@@ -614,12 +644,18 @@ perform_col_merge <- function(data, context) {
         rows_to_format <- base::intersect(which(!(na_1_rows | na_2_rows)), rows)
       }
 
+      body_1_vals <- body[[mutated_column]][rows_to_format]
+      body_1_vals[body_1_vals == "<br />"] <- ""
+
+      body_2_vals <- body[[second_column]][rows_to_format]
+      body_2_vals[body_2_vals == "<br />"] <- ""
+
       body[rows_to_format, mutated_column] <-
         as.character(
           glue_gt(
             list(
-              "1" = body[[mutated_column]][rows_to_format],
-              "2" = body[[second_column]][rows_to_format],
+              "1" = body_1_vals,
+              "2" = body_2_vals,
               "sep" = sep
             ),
             pattern
