@@ -1,8 +1,5 @@
 # Testable version of the `render_formats()` function
 render_formats_test <- function(data,
                                 context) {
-
-  data %>%
-    build_data(context = context) %>%
-    .$`_body`
+  build_data(data, context = context)$`_body`
 }
