@@ -30,16 +30,16 @@ test_that("The `cols_merge()` function works correctly", {
     )
 
   # Expect a characteristic pattern
-  grepl(
+  expect_match(
+    as_latex(tbl_latex) %>% as.character(),
     paste0(
       ".*21.0 & 6 & 160 & 110 & 3.90 \\(2.620\\) & 16.46 & 0 & 1 & 4 & 4",
       ".*21.0 & 6 & 160 & 110 & 3.90 \\(2.875\\) & 17.02 & 0 & 1 & 4 & 4",
       ".*22.8 & 4 & 108 & 93 & 3.85 \\(2.320\\) & 18.61 & 1 & 1 & 4 & 1",
       ".*21.4 & 6 & 258 & 110 & 3.08 \\(3.215\\) & 19.44 & 1 & 0 & 3 & 1",
-      ".*18.7 & 8 & 360 & 175 & 3.15 \\(3.440\\) & 17.02 & 0 & 0 & 3 & 2.*"),
-    tbl_latex %>%
-      as_latex() %>% as.character()) %>%
-    expect_true()
+      ".*18.7 & 8 & 360 & 175 & 3.15 \\(3.440\\) & 17.02 & 0 & 0 & 3 & 2.*"
+    )
+  )
 
   # Create a `tbl_latex` object with `gt()`; merge two columns
   # with a `pattern` and use `c()`
@@ -53,16 +53,16 @@ test_that("The `cols_merge()` function works correctly", {
     )
 
   # Expect a characteristic pattern
-  grepl(
+  expect_match(
+    as_latex(tbl_latex) %>% as.character(),
     paste0(
       ".*21.0 & 6 & 160 & 110 & 3.90 \\(2.620\\) & 16.46 & 0 & 1 & 4 & 4",
       ".*21.0 & 6 & 160 & 110 & 3.90 \\(2.875\\) & 17.02 & 0 & 1 & 4 & 4",
       ".*22.8 & 4 & 108 & 93 & 3.85 \\(2.320\\) & 18.61 & 1 & 1 & 4 & 1",
       ".*21.4 & 6 & 258 & 110 & 3.08 \\(3.215\\) & 19.44 & 1 & 0 & 3 & 1",
-      ".*18.7 & 8 & 360 & 175 & 3.15 \\(3.440\\) & 17.02 & 0 & 0 & 3 & 2.*"),
-    tbl_latex %>%
-      as_latex() %>% as.character()) %>%
-    expect_true()
+      ".*18.7 & 8 & 360 & 175 & 3.15 \\(3.440\\) & 17.02 & 0 & 0 & 3 & 2.*"
+      )
+  )
 
   # Create a `tbl_latex` object with `gt()`; merge two columns, twice,
   # with two different `pattern`s; use `c()`
@@ -81,16 +81,16 @@ test_that("The `cols_merge()` function works correctly", {
     )
 
   # Expect a characteristic pattern
-  grepl(
+  expect_match(
+    as_latex(tbl_latex) %>% as.character(),
     paste0(
       ".*21.0 & 6 & 160 & 110 & 3.90 \\(2.620\\) & 16.46 & 0 & 1 & 4-4",
       ".*21.0 & 6 & 160 & 110 & 3.90 \\(2.875\\) & 17.02 & 0 & 1 & 4-4",
       ".*22.8 & 4 & 108 & 93 & 3.85 \\(2.320\\) & 18.61 & 1 & 1 & 4-1",
       ".*21.4 & 6 & 258 & 110 & 3.08 \\(3.215\\) & 19.44 & 1 & 0 & 3-1",
-      ".*18.7 & 8 & 360 & 175 & 3.15 \\(3.440\\) & 17.02 & 0 & 0 & 3-2.*"),
-    tbl_latex %>%
-      as_latex() %>% as.character()) %>%
-    expect_true()
+      ".*18.7 & 8 & 360 & 175 & 3.15 \\(3.440\\) & 17.02 & 0 & 0 & 3-2.*"
+      )
+    )
 })
 
 test_that("The `cols_merge_uncert()` function works correctly", {
@@ -106,7 +106,8 @@ test_that("The `cols_merge_uncert()` function works correctly", {
     )
 
   # Expect a characteristic pattern
-  grepl(
+  expect_match(
+    as_latex(tbl_latex) %>% as.character(),
     paste0(
       ".*767.6 ± 928.1 & 382.0 & 674.5",
       ".*403.3 ± 461.5 & 15.1 & 242.8",
@@ -117,10 +118,9 @@ test_that("The `cols_merge_uncert()` function works correctly", {
       ".*349.7 ± 307.1 & 566.7 & 542.9",
       ".*63.7 ± 504.3 & 152.0 & 724.5",
       ".*105.4 ± 729.8 & 962.4 & 336.4",
-      ".*924.2 ± 424.6 & 740.8 & 104.2.*"),
-    tbl_latex %>%
-      as_latex() %>% as.character()) %>%
-    expect_true()
+      ".*924.2 ± 424.6 & 740.8 & 104.2.*"
+      )
+    )
 
   # Create a `tbl_latex` object with `gt()`; merge two columns
   # with `cols_merge_uncert()`
@@ -133,7 +133,8 @@ test_that("The `cols_merge_uncert()` function works correctly", {
     )
 
   # Expect a characteristic pattern
-  grepl(
+  expect_match(
+    as_latex(tbl_latex) %>% as.character(),
     paste0(
       ".*767.6 ± 928.1 & 382.0 & 674.5",
       ".*403.3 ± 461.5 & 15.1 & 242.8",
@@ -144,10 +145,9 @@ test_that("The `cols_merge_uncert()` function works correctly", {
       ".*349.7 ± 307.1 & 566.7 & 542.9",
       ".*63.7 ± 504.3 & 152.0 & 724.5",
       ".*105.4 ± 729.8 & 962.4 & 336.4",
-      ".*924.2 ± 424.6 & 740.8 & 104.2.*"),
-    tbl_latex %>%
-      as_latex() %>% as.character()) %>%
-    expect_true()
+      ".*924.2 ± 424.6 & 740.8 & 104.2.*"
+      )
+    )
 
   # Create a `tbl_latex` object with `gt()`; merge two columns, twice,
   # with `cols_merge_uncert()`
@@ -164,7 +164,8 @@ test_that("The `cols_merge_uncert()` function works correctly", {
     )
 
   # Expect a characteristic pattern
-  grepl(
+  expect_match(
+    as_latex(tbl_latex) %>% as.character(),
     paste0(
       ".*767.6 ± 928.1 & 382.0 ± 674.5",
       ".*403.3 ± 461.5 & 15.1 ± 242.8",
@@ -175,10 +176,9 @@ test_that("The `cols_merge_uncert()` function works correctly", {
       ".*349.7 ± 307.1 & 566.7 ± 542.9",
       ".*63.7 ± 504.3 & 152.0 ± 724.5",
       ".*105.4 ± 729.8 & 962.4 ± 336.4",
-      ".*924.2 ± 424.6 & 740.8 ± 104.2.*"),
-    tbl_latex %>%
-      as_latex() %>% as.character()) %>%
-    expect_true()
+      ".*924.2 ± 424.6 & 740.8 ± 104.2.*"
+      )
+  )
 })
 
 test_that("The `cols_merge_range()` function works correctly", {
@@ -194,7 +194,8 @@ test_that("The `cols_merge_range()` function works correctly", {
     )
 
   # Expect a characteristic pattern
-  grepl(
+  expect_match(
+    as_latex(tbl_latex) %>% as.character(),
     paste0(
       ".*767.6–928.1 & 382.0 & 674.5",
       ".*403.3–461.5 & 15.1 & 242.8",
@@ -205,10 +206,9 @@ test_that("The `cols_merge_range()` function works correctly", {
       ".*349.7–307.1 & 566.7 & 542.9",
       ".*63.7–504.3 & 152.0 & 724.5",
       ".*105.4–729.8 & 962.4 & 336.4",
-      ".*924.2–424.6 & 740.8 & 104.2.*"),
-    tbl_latex %>%
-      as_latex() %>% as.character()) %>%
-    expect_true()
+      ".*924.2–424.6 & 740.8 & 104.2.*"
+    )
+  )
 
   # Create a `tbl_latex` object with `gt()`; merge two columns
   # with `cols_merge_range()`
@@ -221,7 +221,8 @@ test_that("The `cols_merge_range()` function works correctly", {
     )
 
   # Expect a characteristic pattern
-  grepl(
+  expect_match(
+    as_latex(tbl_latex) %>% as.character(),
     paste0(
       ".*767.6–928.1 & 382.0 & 674.5",
       ".*403.3–461.5 & 15.1 & 242.8",
@@ -232,10 +233,9 @@ test_that("The `cols_merge_range()` function works correctly", {
       ".*349.7–307.1 & 566.7 & 542.9",
       ".*63.7–504.3 & 152.0 & 724.5",
       ".*105.4–729.8 & 962.4 & 336.4",
-      ".*924.2–424.6 & 740.8 & 104.2.*"),
-    tbl_latex %>%
-      as_latex() %>% as.character()) %>%
-    expect_true()
+      ".*924.2–424.6 & 740.8 & 104.2.*"
+    )
+  )
 
   # Create a `tbl_latex` object with `gt()`; merge two columns, twice,
   # with `cols_merge_range()`
@@ -252,7 +252,8 @@ test_that("The `cols_merge_range()` function works correctly", {
     )
 
   # Expect a characteristic pattern
-  grepl(
+  expect_match(
+    as_latex(tbl_latex) %>% as.character(),
     paste0(
       ".*767.6–928.1 & 382.0–674.5",
       ".*403.3–461.5 & 15.1–242.8",
@@ -263,8 +264,7 @@ test_that("The `cols_merge_range()` function works correctly", {
       ".*349.7–307.1 & 566.7–542.9",
       ".*63.7–504.3 & 152.0–724.5",
       ".*105.4–729.8 & 962.4–336.4",
-      ".*924.2–424.6 & 740.8–104.2.*"),
-    tbl_latex %>%
-      as_latex() %>% as.character()) %>%
-    expect_true()
+      ".*924.2–424.6 & 740.8–104.2.*"
+    )
+  )
 })
