@@ -1,4 +1,4 @@
-test_that("the `fmt_engineering()` function works correctly in the LaTeX context", {
+test_that("The `fmt_engineering()` function works correctly in the LaTeX context", {
 
   # Create an input data frame with a single numeric column
   data_tbl <-
@@ -169,7 +169,7 @@ test_that("the `fmt_engineering()` function works correctly in the LaTeX context
   expect_equal(
     (tab %>%
        fmt_engineering(
-         columns = "num", decimals = 3, force_sign = TRUE) %>%
+         columns = "num", decimals = 3, force_sign_m = TRUE) %>%
        render_formats_test("latex"))[["num"]],
     c(
       "$+82.030 \\times 10^{30}$", "$+829.300 \\times 10^{18}$",
@@ -191,7 +191,7 @@ test_that("the `fmt_engineering()` function works correctly in the LaTeX context
   expect_equal(
     (tab %>%
        fmt_engineering(
-         columns = "num", pattern = "*{x}*", force_sign = TRUE) %>%
+         columns = "num", pattern = "*{x}*", force_sign_m = TRUE) %>%
        render_formats_test("latex"))[["num"]],
     c(
       "*$+82.03 \\times 10^{30}$*", "*$+829.30 \\times 10^{18}$*",
@@ -251,7 +251,7 @@ test_that("the `fmt_engineering()` function works correctly in the LaTeX context
   )
 })
 
-test_that("`fmt_engineering() can handle extremely large and small values", {
+test_that("The `fmt_engineering() fn can handle extremely large and small values", {
 
   # Create an input data frame with very large and very small numbers
   # (both positive and negative)
